==> nextcloud-11.0.3-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/federatedfilesharing/l10n/it.js <==
OC.L10N.register(
    "federatedfilesharing",
    {
    "Federated sharing" : "Condivisione federata",
    "Do you want to add the remote share {name} from {owner}@{remote}?" : "Vuoi aggiungere la condivisione remota {name} da {owner}@{remote}?",
    "Remote share" : "Condivisione remota",
    "Remote share password" : "Password della condivisione remota",
    "Cancel" : "Annulla",
    "Add remote share" : "Aggiungi condivisione remota",
    "Copy" : "Copia",
    "Copied!" : "Copiato!",
    "Not supported!" : "Non supportato!",
    "Press ⌘-C to copy." : "Premi ⌘-C per copiare.",
    "Press Ctrl-C to copy." : "Premi Ctrl-C per copiare.",
    "Invalid Federated Cloud ID" : "ID di cloud federata non valido",
    "Server to server sharing is not enabled on this server" : "La condivisione tra server non è abilitata su questo server",
    "Couldn't establish a federated share." : "Impossibile stabilire una condivisione federata.",
    "Couldn't establish a federated share, maybe the password was wrong." : "Impossibile stabilire una condivisione federata, forse la password non è corretta.",
    "Federated Share request was successful, you will receive a invitation. Check your notifications." : "La richiesta della condivisione federata è stata eseguita con successo, riceverai un invito. Controlla le tue notifiche.",
    "The mountpoint name contains invalid characters." : "Il nome del punto di mount contiene caratteri non validi.",
    "Not allowed to create a federated share with the owner." : "Non è consentito creare una condivisione federata con il proprietario.",
    "Invalid or untrusted SSL certificate" : "Certificato SSL non valido o non attendibile",
    "Could not authenticate to remote share, password might be wrong" : "Impossibile autenticarsi sulla condivisione remota, la password potrebbe essere errata",
    "Storage not valid" : "Archiviazione non valida",
    "Federated Share successfully added" : "Condivisione federata aggiunta con successo",
    "Couldn't add remote share" : "Impossibile aggiungere la condivisione remota",
    "Sharing %s failed, because this item is already shared with %s" : "Condivisione di %s non riuscita, poiché l'oggetto è già condiviso con %s",
    "Not allowed to create a federated share with the same user" : "Non è consentito creare una condivisione federata con lo stesso utente",
    "File is already shared with %s" : "Il file è già condiviso con %s",
    "Sharing %s failed, could not find %s, maybe the server is currently unreachable or uses a self-signed certificate." : "La condivisione di %s non è riuscita, impossibile trovare %s, è probabile che il server non sia al momento raggiungibile o che utilizzi un certificato auto-firmato.",
    "Could not find share" : "Impossibile trovare la condivisione",
    "You received \"%3$s\" as a remote share from %1$s (on behalf of %2$s)" : "Hai ricevuto \"%3$s\" come condivisione remota da %1$s (per conto di %2$s)",
    "You received {share} as a remote share from {user} (on behalf of {behalf})" : "Hai ricevuto {share} come condivisione remota da {user} (per conto di {behalf})",
    "You received \"%3$s\" as a remote share from %1$s" : "Hai ricevuto \"%3$s\" come condivisione remota da %1$s",
    "You received {share} as a remote share from {user}" : "Hai ricevuto {share} come condivisione remota da {user}",
    "Accept" : "Accetta",
    "Decline" : "Rifiuta",
    "Share with me through my #Nextcloud Federated Cloud ID, see %s" : "Condividi con me attraverso il mio ID di cloud federata #Nextcloud, vedi %s",
    "Share with me through my #Nextcloud Federated Cloud ID" : "Condividi con me attraverso il mio ID di cloud federata #Nextcloud",
    "Federated Cloud Sharing" : "Condivisione cloud federata",
    "Open documentation" : "Apri la documentazione",
    "Allow users on this server to send shares to other servers" : "Consenti agli utenti su questo server di inviare condivisioni ad altri server",
    "Allow users on this server to receive shares from other servers" : "Consenti agli utenti su questo server di ricevere condivisioni da altri server",
    "Federated Cloud" : "Cloud federata",
    "Your Federated Cloud ID:" : "Il tuo ID di cloud federata:",
    "Share it:" : "Condividilo:",
    "Add to your website" : "Aggiungi al tuo sito web",
    "Share with me via Nextcloud" : "Condividi con me tramite Nextcloud",
    "HTML Code:" : "Codice HTML:",
    "Search global and public address book for users" : "Cerca gli utenti nella rubrica globale e pubblica"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-12.0.0-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/federatedfilesharing/l10n/it.js <==
OC.L10N.register(
    "federatedfilesharing",
    {
    "Federated sharing" : "Condivisione federata",
    "Do you want to add the remote share {name} from {owner}@{remote}?" : "Vuoi aggiungere la condivisione remota {name} da {owner}@{remote}?",
    "Remote share" : "Condivisione remota",
    "Remote share password" : "Password della condivisione remota",
    "Cancel" : "Annulla",
    "Add remote share" : "Aggiungi condivisione remota",
    "Copy" : "Copia",
    "Copied!" : "Copiato!",
    "Not supported!" : "Non supportato!",
    "Press ⌘-C to copy." : "Premi ⌘-C per copiare.",
    "Press Ctrl-C to copy." : "Premi Ctrl-C per copiare.",
    "Invalid Federated Cloud ID" : "ID di cloud federata non valido",
    "Server to server sharing is not enabled on this server" : "La condivisione tra server non è abilitata su questo server",
    "Couldn't establish a federated share." : "Impossibile stabilire una condivisione federata.",
    "Couldn't establish a federated share, maybe the password was wrong." : "Impossibile stabilire una condivisione federata, forse la password non è corretta.",
    "Federated Share request was successful, you will receive a invitation. Check your notifications." : "La richiesta della condivisione federata è stata eseguita con successo, riceverai un invito. Controlla le tue notifiche.",
    "The mountpoint name contains invalid characters." : "Il nome del punto di mount contiene caratteri non validi.",
    "Not allowed to create a federated share with the owner." : "Non è consentito creare una condivisione federata con il proprietario.",
    "Invalid or untrusted SSL certificate" : "Certificato SSL non valido o non attendibile",
    "Could not authenticate to remote share, password might be wrong" : "Impossibile autenticarsi sulla condivisione remota, la password potrebbe essere errata",
    "Storage not valid" : "Archiviazione non valida",
    "Federated Share successfully added" : "Condivisione federata aggiunta con successo",
    "Couldn't add remote share" : "Impossibile aggiungere la condivisione remota",
    "Sharing %s failed, because this item is already shared with %s" : "Condivisione di %s non riuscita, poiché l'oggetto è già condiviso con %s",
    "Not allowed to create a federated share with the same user" : "Non è consentito creare una condivisione federata con lo stesso utente",
    "File is already shared with %s" : "Il file è già condiviso con %s",
    "Sharing %s failed, could not find %s, maybe the server is currently unreachable or uses a self-signed certificate." : "La condivisione di %s non è riuscita, impossibile trovare %s, è probabile che il server non sia al momento raggiungibile o che utilizzi un certificato auto-firmato.",
    "Could not find share" : "Impossibile trovare la condivisione",
    "You received \"%3$s\" as a remote share from %1$s (on behalf of %2$s)" : "Hai ricevuto \"%3$s\" come condivisione remota da %1$s (per conto di %2$s)",
    "You received {share} as a remote share from {user} (on behalf of {behalf})" : "Hai ricevuto {share} come condivisione remota da {user} (per conto di {behalf})",
    "You received \"%3$s\" as a remote share from %1$s" : "Hai ricevuto \"%3$s\" come condivisione remota da %1$s",
    "You received {share} as a remote share from {user}" : "Hai ricevuto {share} come condivisione remota da {user}",
    "Accept" : "Accetta",
    "Decline" : "Rifiuta",
    "Share with me through my #Nextcloud Federated Cloud ID, see %s" : "Condividi con me attraverso il mio ID di cloud federata #Nextcloud, vedi %s",
    "Share with me through my #Nextcloud Federated Cloud ID" : "Condividi con me attraverso il mio ID di cloud federata #Nextcloud",
    "Federated Cloud Sharing" : "Condivisione cloud federata",
    "Open documentation" : "Apri la documentazione",
    "Allow users on this server to send shares to other servers" : "Consenti agli utenti su questo server di inviare condivisioni ad altri server",
    "Allow users on this server to receive shares from other servers" : "Consenti agli utenti su questo server di ricevere condivisioni da altri server",
    "Federated Cloud" : "Cloud federata",
    "Your Federated Cloud ID:" : "Il tuo ID di cloud federata:",
    "Add to your website" : "Aggiungi al tuo sito web",
    "Share with me via Nextcloud" : "Condividi con me tramite Nextcloud",
    "HTML Code:" : "Codice HTML:",
    "Search global and public address book for users" : "Cerca gli utenti nella rubrica globale e pubblica",
    "Share it:" : "Condividilo:"
},
"nplurals=2; plural=(n != 1);");
